@@ -178,23 +178,26 @@ class PriceCalculator(object):
 
         if object.get_for_sale():
             if object.is_variant() and not object.active_for_sale_price:
-                price = object.parent.get_for_sale_price(self.request)
+                price = object.parent.get_for_sale_price(self.request, with_properties)
             else:
-                price = object.get_for_sale_price(self.request)
+                price = object.get_for_sale_price(self.request, with_properties)
         else:
             if object.is_variant() and not object.active_price:
                 price = object.parent.price
             else:
                 price = object.price
 
-        if with_properties and object.is_configurable_product():
-            price += object.get_default_properties_price()
-
         return price
 
     def get_price_net(self, with_properties=True):
         """
         Returns the net price of the product.
+
+        **Parameters:**
+
+        with_properties
+            If the instance is a configurable product and with_properties is
+            True the prices of the default properties are added to the price.
         """
         raise NotImplementedError
 
@@ -316,6 +319,12 @@ class PriceCalculator(object):
     def get_base_price(self, with_properties=True):
         """
         Returns the base price of the product.
+
+        **Parameters:**
+
+        with_properties
+            If the instance is a configurable product and with_properties is
+            True the prices of the default properties are added to the price.
         """
         try:
             return self.get_price(with_properties) / self.product.get_base_price_amount()
@@ -325,6 +334,12 @@ class PriceCalculator(object):
     def get_base_price_net(self, with_properties=True):
         """
         Returns the net base price of the product.
+
+        **Parameters:**
+
+        with_properties
+            If the instance is a configurable product and with_properties is
+            True the prices of the default properties are added to the price.
         """
         try:
             return self.get_price_net(with_properties) / self.product.get_base_price_amount()
@@ -334,29 +349,53 @@ class PriceCalculator(object):
     def get_base_price_gross(self, with_properties=True):
         """
         Returns the gross base price of the product.
+
+        **Parameters:**
+
+        with_properties
+            If the instance is a configurable product and with_properties is
+            True the prices of the default properties are added to the price.
         """
         try:
             return self.get_price_gross(with_properties) / self.product.get_base_price_amount()
         except (TypeError, ZeroDivisionError):
             return 0.0
 
-    def get_base_packing_price(self):
+    def get_base_packing_price(self, with_properties=True):
         """
         Returns the base packing price of the product.
-        """
-        return self.get_price(self.request) * self._calc_packing_amount()
 
-    def get_base_packing_price_net(self):
+        **Parameters:**
+
+        with_properties
+            If the instance is a configurable product and with_properties is
+            True the prices of the default properties are added to the price.
+        """
+        return self.get_price(with_properties) * self._calc_packing_amount()
+
+    def get_base_packing_price_net(self, with_properties=True):
         """
         Returns the base packing net price of the product.
-        """
-        return self.get_price_net(self.request) * self._calc_packing_amount()
 
-    def get_base_packing_price_gross(self):
+        **Parameters:**
+
+        with_properties
+            If the instance is a configurable product and with_properties is
+            True the prices of the default properties are added to the price.
+        """
+        return self.get_price_net(with_properties) * self._calc_packing_amount()
+
+    def get_base_packing_price_gross(self, with_properties=True):
         """
         Returns the base packing gross price of the product.
+
+        **Parameters:**
+
+        with_properties
+            If the instance is a configurable product and with_properties is
+            True the prices of the default properties are added to the price.
         """
-        return self.get_price_gross(self.request) * self._calc_packing_amount()
+        return self.get_price_gross(with_properties) * self._calc_packing_amount()
 
     def get_customer_tax_rate(self):
         """
