@@ -12,6 +12,8 @@ from models import RecentProductsPortlet
 from models import RelatedProductsPortlet
 from models import TextPortlet
 from models import TopsellerPortlet
+from models import ForsalePortlet
+from models import FeaturedPortlet
 
 # 3rd party imports
 import portlets
@@ -31,5 +33,7 @@ def register_lfs_portlets(sender, **kwargs):
         register_portlet(RelatedProductsPortlet, "Related Products")
         register_portlet(TextPortlet, "Text")
         register_portlet(TopsellerPortlet, "Topseller")
+        register_portlet(ForsalePortlet, "For sale")
+        register_portlet(FeaturedPortlet, "Featured Products")
 
 post_syncdb.connect(register_lfs_portlets)
