@@ -1,5 +1,6 @@
 # django imports
 from django import template
+from django.conf import settings
 from django.core.cache import cache
 from django.utils.translation import ugettext_lazy as _
 
@@ -18,6 +19,7 @@ from lfs.portlet.models import TopsellerPortlet
 
 register = template.Library()
 
+
 # TODO: Make a better reuse of django-portlets portlet slot
 @register.inclusion_tag('portlets/portlet_slot.html', takes_context=True)
 def lfs_portlet_slot(context, slot_name):
@@ -25,21 +27,24 @@ def lfs_portlet_slot(context, slot_name):
     implements the ``get_parent_for_portlets`` method the portlets of the
     parent of the instance are also added.
     """
+    request = context.get("request")
+
     instance = context.get("category") or \
                context.get("product") or \
-               lfs.core.utils.get_default_shop()
+               context.get("page") or \
+               lfs.core.utils.get_default_shop(request)
 
-    cache_key = "lfs-portlet-slot-%s-%s-%s" % (slot_name, instance.__class__.__name__, instance.id)
+    cache_key = "%s-lfs-portlet-slot-%s-%s-%s" % (settings.CACHE_MIDDLEWARE_KEY_PREFIX, slot_name, instance.__class__.__name__, instance.id)
     temp = cache.get(cache_key)
 
     if temp is None:
         try:
             slot = Slot.objects.get(name=slot_name)
         except Slot.DoesNotExist:
-            return { "portlets" : [] }
+            return {"portlets": []}
 
         # Get portlets for given instance
-        temp = portlets.utils.get_portlets(slot, instance)
+        temp = portlets.utils.get_portlets(instance, slot)
 
         # Get inherited portlets
         try:
@@ -62,7 +67,7 @@ def lfs_portlet_slot(context, slot_name):
             if instance is None:
                 break
 
-            parent_portlets = portlets.utils.get_portlets(slot, instance)
+            parent_portlets = portlets.utils.get_portlets(instance, slot)
             parent_portlets.reverse()
             for p in parent_portlets:
                 if p not in temp:
@@ -74,7 +79,8 @@ def lfs_portlet_slot(context, slot_name):
     for portlet in temp:
         rendered_portlets.append(portlet.render(context))
 
-    return { "portlets" : rendered_portlets }
+    return {"portlets": rendered_portlets}
+
 
 # Inclusion tags to render portlets. This can be used if one wants to display
 # portlets without the possibility to manage them via the UI.
@@ -89,9 +95,10 @@ def lfs_cart_portlet(context, title=None):
     portlet.title = title
 
     return {
-        "html" : portlet.render(context)
+        "html": portlet.render(context)
     }
 
+
 @register.inclusion_tag('lfs/portlets/portlet.html', takes_context=True)
 def lfs_categories_portlet(context, title=None):
     """Tag to render the related products portlet.
@@ -103,9 +110,10 @@ def lfs_categories_portlet(context, title=None):
     portlet.title = title
 
     return {
-        "html" : portlet.render(context)
+        "html": portlet.render(context)
     }
 
+
 @register.inclusion_tag('lfs/portlets/portlet.html', takes_context=True)
 def lfs_pages_portlet(context, title=None):
     """Tag to render the pages portlet.
@@ -117,9 +125,10 @@ def lfs_pages_portlet(context, title=None):
     portlet.title = title
 
     return {
-        "html" : portlet.render(context)
+        "html": portlet.render(context)
     }
 
+
 @register.inclusion_tag('lfs/portlets/portlet.html', takes_context=True)
 def lfs_recent_products_portlet(context, title=None):
     """Tag to render the recent products portlet.
@@ -131,9 +140,10 @@ def lfs_recent_products_portlet(context, title=None):
     portlet.title = title
 
     return {
-        "html" : portlet.render(context)
+        "html": portlet.render(context)
     }
 
+
 @register.inclusion_tag('lfs/portlets/portlet.html', takes_context=True)
 def lfs_related_products_portlet(context, title=None):
     """Tag to render the related products portlet.
@@ -145,9 +155,10 @@ def lfs_related_products_portlet(context, title=None):
     portlet.title = title
 
     return {
-        "html" : portlet.render(context)
+        "html": portlet.render(context)
     }
 
+
 @register.inclusion_tag('lfs/portlets/portlet.html', takes_context=True)
 def lfs_topseller_portlet(context, title=None, limit=5):
     """Tag to render the related products portlet.
@@ -160,5 +171,5 @@ def lfs_topseller_portlet(context, title=None, limit=5):
     portlet.limit = limit
 
     return {
-        "html" : portlet.render(context)
-    }
\ No newline at end of file
+        "html": portlet.render(context)
+    }
